@@ -14,7 +14,7 @@ Copyright (c) 2020, Vitor Avancini
   See the License for the specific language governing permissions and
   limitations under the License.
 """
-from typing import List, Optional, Tuple, Any
+from typing import List, Optional, Tuple, Any, Dict, Union
 from contextlib import contextmanager
 from dataclasses import dataclass, field
 import enum
@@ -24,20 +24,13 @@ import cx_Oracle
 from cx_Oracle import Connection
 
 import dbt.exceptions
-from dbt.helper_types import Port
 
 from dbt.adapters.base import Credentials
 from dbt.adapters.sql import SQLConnectionManager
 from dbt.contracts.connection import AdapterResponse
+from dbt.events import AdapterLogger
 
-# dbt.events was introduced in dbt-core==1.0.0 which only supports Python 3.7
-# For Python 3.6, we fallback to the old logger in dbt.logger.
-try:
-    from dbt.events import AdapterLogger
-    logger = AdapterLogger("oracle")
-except ImportError:
-    from dbt.logger import GLOBAL_LOGGER as logger
-
+logger = AdapterLogger("oracle")
 
 
 class OracleConnectionMethod(enum.Enum):
@@ -56,7 +49,8 @@ class OracleAdapterCredentials(Credentials):
     # Mandatory required arguments.
     user: str
     password: str
-    database: str
+    # Specifying database is optional
+    database: Optional[str]
 
     # OracleConnectionMethod.TNS
     tns_name: Optional[str] = None
@@ -64,7 +58,7 @@ class OracleAdapterCredentials(Credentials):
     # OracleConnectionMethod.HOST
     protocol: Optional[str] = None
     host: Optional[str] = None
-    port: Optional[Port] = None
+    port: Optional[Union[str, int]] = None
     service: Optional[str] = None
 
     # OracleConnectionMethod.CONNECTION_STRING
@@ -104,6 +98,14 @@ class OracleAdapterCredentials(Credentials):
             'cclass', 'purity'
         )
 
+    @classmethod
+    def __pre_deserialize__(cls, data: Dict[Any, Any]) -> Dict[Any, Any]:
+        # If database is not defined as adapter credentials
+        data = super().__pre_deserialize__(data)
+        if "database" not in data:
+            data["database"] = None
+        return data
+
     def connection_method(self) -> OracleConnectionMethod:
         """Return an OracleConnecitonMethod inferred from the configuration"""
         if self.connection_string:
@@ -124,16 +126,8 @@ class OracleAdapterCredentials(Credentials):
         if method == OracleConnectionMethod.CONNECTION_STRING:
             return self.connection_string
 
-        # Assume host connection method OracleConnectionMethod.HOST
-
-        # If the 'service' property is not provided, use 'database' property for
-        # purposes of connecting.
-        if self.service:
-            service = self.service
-        else:
-            service = self.database
-
-        return f'{self.protocol}://{self.host}:{self.port}/{service}'
+        # Assume host connection method OracleConnectionMethod.HOST and necessary parameters are defined
+        return f'{self.protocol}://{self.host}:{self.port}/{self.service}'
 
 
 class OracleAdapterConnectionManager(SQLConnectionManager):
